@@ -106,7 +106,7 @@
 ##'   use \code{year = c(1990, 1995, 2000)} for example.
 ##'
 ##' @param local File path to .RData trajectory files run by user and
-##' not stored on the KCL web server. These files would have been
+##' not stored on the Ricardo web server. These files would have been
 ##' generated from the Hysplit trajectory code shown in the appendix
 ##' of the openair manual. An example would be \code{local =
 ##' 'c:/users/david/TrajFiles/'}.
@@ -131,45 +131,45 @@
 ##' \dontrun{theData <- importAURN(site = "kc1", year = 2009)
 ##' mytraj <- merge(mytraj, theData, by = "date")}
 importTraj <- function(site = "london", year = 2009, local = NA) {
-
-    ## get rid of R check annoyances
-    traj = NULL
-
-    if (length(site) > 1) stop("Only one site can be imported at a time.")
-    site <- tolower(site)
-
-    files <- lapply(site, function (x) paste(x, year, sep = ""))
-    files <- do.call(c, files)
-
-    loadData <- function(x) {
-        tryCatch({
-
-            if (is.na(local)) {
-                fileName <- paste("http://www.erg.kcl.ac.uk/downloads/Policy_Reports/Traj/", x, ".RData",
-                                  sep = "")
-
-                con <- url(fileName)
-                load(con)
-                close(con)
-
-            } else { ## load from local file system
-
-                con <- paste(local, x, ".RData", sep = "")
-                load(con)
-
-            }
-
-
-            traj
-        },
-                 error = function(ex) {cat(x, "does not exist - ignoring that one.\n")})
-    }
-
-    thedata <- lapply(files, loadData)
-    thedata <- do.call(bind_rows, thedata)
-
-    ## change names
-    names(thedata) <- tolower(names(thedata))
-
-    thedata
+  
+  ## get rid of R check annoyances
+  traj = NULL
+  
+  if (length(site) > 1) stop("Only one site can be imported at a time.")
+  site <- tolower(site)
+  
+  files <- lapply(site, function (x) paste(x, year, sep = ""))
+  files <- do.call(c, files)
+  
+  loadData <- function(x) {
+    tryCatch({
+      
+      if (is.na(local)) {
+        fileName <- paste("http://met-data.ricardo-aea.com/trajectories/", x, ".RData",
+                          sep = "")
+        
+        con <- url(fileName)
+        load(con)
+        close(con)
+        
+      } else { ## load from local file system
+        
+        con <- paste(local, x, ".RData", sep = "")
+        load(con)
+        
+      }
+      
+      
+      traj
+    },
+    error = function(ex) {cat(x, "does not exist - ignoring that one.\n")})
+  }
+  
+  thedata <- lapply(files, loadData)
+  thedata <- do.call(bind_rows, thedata)
+  
+  ## change names
+  names(thedata) <- tolower(names(thedata))
+  
+  thedata
 }
